@@ -71,16 +71,16 @@ if they are not specified. The mandatory connection parameters can differ for di
 drivers. Most of them need at least a user name and password.
 
 .. hint::
-    Most database drivers like e.g. `psycopg2 <http://http://initd.org/psycopg/docs/module.html>` or
-    :ref:`pg8000 <https://kite.com/python/docs/pg8000.connect>` for Postgres databases
+    Most database drivers like e.g. `psycopg2 <http://initd.org/psycopg/docs/module.html>`_ or
+    `pg8000 <https://kite.com/python/docs/pg8000.connect>`_ for Postgres databases
     are supporting all of these connection parameter keys. For others like e.g.
-    :ref:`cx_Oracle <https://cx-oracle.readthedocs.io/en/7.2/module.html>` which are not supporting
+    `cx_Oracle <https://cx-oracle.readthedocs.io/en/7.2/module.html>`_ which are not supporting
     some of them (like e.g. `host` and `dbname`) you may also need to overwrite the
     :meth:`~DbBase.connect_params` method for to convert/adopt unsupported connection parameter keys.
 
 Alternatively you can provide the connection parameters needed by the database driver connector
 with a single database url string in the
-:ref:`SQLAlchemy Database URL format <https://docs.sqlalchemy.org/en/13/core/engines.html#database-urls>`::
+`SQLAlchemy Database URL format <https://docs.sqlalchemy.org/en/13/core/engines.html#database-urls>`_::
 
     dialect+driver://user:password@host:port/dbname
 
@@ -98,7 +98,7 @@ bind variables format
 ---------------------
 
 Bind variables in your sql query strings have to be formatted in the
-:pep:`named parameter style <249>/#paramstyle`. If your database driver is only supporting the
+:pep:`named parameter style <249#paramstyle>`. If your database driver is only supporting the
 `pyformat` parameter style, then overload the __init__ method and set the :attr:`~DbBase.param_style`
 to ``'pyformat'`` and all sql query strings will be automatically converted by :class:`DbBase`
 before they get sent to the database::
@@ -120,7 +120,7 @@ from ae.lockname import NamedLocks                              # type: ignore
 from ae.sys_core import SystemBase, SystemConnectorBase         # type: ignore  # for mypy
 
 
-__version__ = '0.0.11'
+__version__ = '0.0.12'
 
 
 NAMED_BIND_VAR_PREFIX: str = ':'        #: character for to mark a bind variable in a sql query
